@@ -40,7 +40,7 @@ program draw
   &                    tmin, tmax, fname,  &
   &                    txtname, cont_val, shade_val, vx_val, vy_val,  &
   &                    cmin, cmax, smin, smax, x_axis, y_axis, t_axis,  &
-  &                    sfact, cfact, vxfact, vyfact, title
+  &                    sfact, cfact, vxfact, vyfact, xscale, title
   read(5,nml=drawinput)
 
   allocate(x(nx))
@@ -170,7 +170,6 @@ program draw
      call nearest_search_1d( t, tmax, tdmax )
   end if
 
-  xscale=0.025
   if(xmax/=xmin.and.ymax/=ymin)then
      call calc_vscale( (/(xmax-xmin), (ymax-ymin)/), (/0.6, 0.6/), xscale, yscale )
 !  yscale=yscale
