@@ -364,6 +364,12 @@ program sound_1d
         if(idz_min<1)then
            idz_min=1
         end if
+        !-- Only Hodograph operation
+        write(*,*) "#### MESSAGE ###"
+        write(*,*) "At Hodograph : the lowest point is forced to vanish."
+        draw_tate(idz_min,4)=0.0
+        draw_yoko(idz_min,4)=0.0
+        draw_yoko(idz_min,1)=0.0
         call interpo_search_1d( height, draw_region_z(2), idz_max )
 
         call Dcl_PL( 'l', trim(fname(2,i)),  &
