@@ -9,6 +9,7 @@ program sound_2d
   use basis
   use Statistics
   use Thermo_Function
+  use Max_Min
 
   implicit none
 
@@ -31,7 +32,7 @@ program sound_2d
   integer, allocatable, dimension(:) :: o_flag  ! 
   integer, allocatable, dimension(:) :: c_flag  ! 
 !-- tmp
-  integer :: nttmp, i, j, k, i_undef
+  integer :: nttmp, i, j, k, i_undef, i_tmp
 !-- parameter
   integer, parameter :: col_num=6
   integer, parameter :: skip_num=2
@@ -53,6 +54,7 @@ program sound_2d
   real, allocatable, dimension(:,:,:) :: val_draw   ! ѿ
   real :: undef
   real :: conv_undef
+  real :: ymin, ymax
 !-- tmp
   real, dimension(2) :: pt_tmp, ept_tmp, sept_tmp, rh_tmp, s_int, c_int
 
@@ -103,7 +105,7 @@ program sound_2d
 
 !-- DCL set
   call SGISET('IFONT', 2)
-  call UZFACT(0.65)
+  call UZFACT(0.6)
   call DclSetParm( 'ENABLE_CONTOUR_MESSAGE', .false. )
   CALL GLRSET( 'RMISS', undef )
   CALL GLLSET( 'LMISS', .TRUE. )
@@ -121,9 +123,15 @@ program sound_2d
   start_day%year_d=year_v(1)
   start_day%month_d=month_v(1)
   start_day%day_d=day_v(1)
+  start_day%hour_d=hour_v(1)
+  start_day%min_d=0
+  start_day%sec_d=0
   end_day%year_d=year_v(nt)
   end_day%month_d=month_v(nt)
   end_day%day_d=day_v(nt)
+  end_day%hour_d=hour_v(nt)
+  end_day%min_d=0
+  end_day%sec_d=0
   days=counter_day( start_day, end_day )-1
   stime%year=year_v(1)
   stime%month=month_v(1)
@@ -146,7 +154,7 @@ program sound_2d
 
   do i=1,nt
      if(trim(fname(1,i))/='unknown')then
-        nttmp=line_number_counter( trim(fname(1,i)) ) -2
+        nttmp=line_number_counter( trim(fname(1,i)) ) -skip_num
         allocate(val_w(col_num,nttmp))
         allocate(val_f(col_num,nttmp))
         call read_file_text( trim(fname(1,i)), col_num, nttmp, val_w,  &
@@ -231,7 +239,15 @@ program sound_2d
 
      do j=1,col_num+4
         do k=1,nz
-           val_draw(j,i,k)=val_inter(j,k)
+           if(j==4)then  ! ˤĤƤν.
+              if(val_inter(j,k)/=undef)then
+                 val_draw(j,i,k)=val_inter(j,k)*1.0e3
+              else
+                 val_draw(j,i,k)=undef
+              end if
+           else
+              val_draw(j,i,k)=val_inter(j,k)
+           end if
         end do
      end do
 
@@ -429,11 +445,15 @@ program sound_2d
            tmp_c=trim(fname(o_flag(j),1))//  &
   &             '('//trim(fname(o_flag(j),2))//')'
 
+           call min_val_1d( yline(i_undef:nt-2,j), i_tmp, ymin, undef )
+           call max_val_1d( yline(i_undef:nt-2,j), i_tmp, ymax, undef )
+
            call Dcl_PL_Calendar( 'l', '',   &
   &             tline(i_undef:nt-2,j:j), yline(i_undef:nt-2,j:j),  &
   &             tline(i_undef:nt-2,j:j), yline(i_undef:nt-2,j:j),  &
   &             (/trim(tmp_c), trim(tmp_c)/),  &
   &             stime, days, viewx_int=vx, viewy_int=vy(j,:),  &
+  &             x_int=(/tline(1,1),tline(nt-2,1)/), y_int=(/ymin,ymax/),  &
   &             no_frame=fflag )
         end do
 
@@ -462,10 +482,17 @@ program sound_2d
               i_undef=i_undef+1
            end if
         end do
+
+        call min_val_2d( yline(i_undef:nt-2,1:c_flag(j)),  &
+  &                      i_tmp, i_tmp, ymin, undef )
+        call max_val_2d( yline(i_undef:nt-2,1:c_flag(j)),  &
+  &                      i_tmp, i_tmp, ymax, undef )
+
         call Dcl_PL_Calendar( 'l', '',  &
   &          tline(i_undef:nt-2,1:c_flag(j)), yline(i_undef:nt-2,1:c_flag(j)),  &
   &          tline(i_undef:nt-2,1:c_flag(j)), yline(i_undef:nt-2,1:c_flag(j)),  &
-  &          (/'', trim(tmp_c)/), stime, days )
+  &          (/'', trim(tmp_c)/), stime, days,  &
+  &          x_int=(/tline(1,1),tline(nt-2,1)/), y_int=(/ymin,ymax/) )
 
      end if
 
