@@ -557,6 +557,53 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function qvTv_2_T( qv, Tv, dl )  ! Ȳ٤鲹٤׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: qv  !  [kg / kg]
+  real, intent(in) :: Tv  !  [K]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: eps
+
+  eps=Rd/Rv
+  qvTv_2_T=Tv*(1.0+qv)/(1.0+qv/eps)
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'qvTv_2_T', qvTv_2_T, 'K' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function TvT_2_qv( Tv, T, dl)  ! ٤Ȳ٤׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: Tv  !  [K]
+  real, intent(in) :: T   !  [K]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: eps
+
+  eps=Rd/Rv
+
+  if(Tv/=T)then
+     TvT_2_qv=eps*((T-Tv)/(eps*Tv-T))
+  else
+     TvT_2_qv=0.0
+  end if
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'TvT_2_qv', TvT_2_qv, 'kg kg-1' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 real function TqvP_2_thetav( T, qv, P, dl )  ! , , Ϥ鲾̤׻.
   use Thermo_Const
   implicit none
@@ -580,6 +627,58 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function thetavqvP_2_T( ptv, qv, P, dl )  ! , , Ϥ鲹٤׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: ptv !  [K]
+  real, intent(in) :: qv  !  [kg / kg]
+  real, intent(in) :: P   !  [Pa]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: kappa, Tv
+
+  kappa=Rd/cpd
+  Tv=ptv*exner_func_dry( P )
+  thetavqvP_2_T=qvTv_2_T( qv, Tv )
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'thetavqvP_2_T', thetavqvP_2_T, 'K' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function TthetavP_2_qv( T, thetav, P, dl )  ! , , Ϥ׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: T       !  [K]
+  real, intent(in) :: thetav  !  [K]
+  real, intent(in) :: P       !  [Pa]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: Tv, eps, exn
+
+  eps=Rd/Rv
+
+  exn=exner_func_dry( P )
+
+  if(T/=exn*thetav)then
+     TthetavP_2_qv=eps*((T-exn*thetav)/(eps*exn*thetav-T))
+  else
+     TthetavP_2_qv=0.0
+  end if
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'TthetavP_2_qv', TthetavP_2_qv, 'kg kg-1' )
+  end if
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 real function exner_func_dry(P, dl)  ! 絤ˤĤƤΥʡؿ׻
   use Thermo_Const
   implicit none
